==> haskell-hasql-dynamic-statements-0.3.1.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-KNcqiEdNjdBv4LYlkSKzr
key:                  hasql-dynamic-statements-0.3.1.1-KNcqiEdNjdBv4LYlkSKzr
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  a72be560aa9500437a23d9a7b02aff3b
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-KNcqiEdNjdBv4LYlkSKzr
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    hasql-1.5.0.4-86xscm40DS691oAAJN41P
    hasql-implicits-0.1.0.5-4z5InuQ2qM72K63cUryY9q
    ptr-0.16.8.4-4y7W4HllsjEBA8dMcsvpF4

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-dynamic-statements-0.3.1.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-HctZ5cVRNXgCH5uBs2vrca
key:                  hasql-dynamic-statements-0.3.1.1-HctZ5cVRNXgCH5uBs2vrca
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  70ff2952a8959b79e766e81163030539
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-HctZ5cVRNXgCH5uBs2vrca
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    hasql-1.5.0.4-JTJ1SKZpt3PAxXoDREcwiW
    hasql-implicits-0.1.0.5-55x2amK1eHk8maHpfJkcnA
    ptr-0.16.8.4-9fo5rmJ7iCs7O5YkoR0tjX

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
